@@ -593,6 +593,8 @@ class Main(cmd.Cmd):
         self.bot.conversation.chat_history = click.prompt(
             "Introductory prompt", default=self.bot.conversation.intro
         )
+        if hasattr(self.bot, "reset"):
+            self.bot.reset()
         click.secho("Conversation reset successfully. New one created.", fg="cyan")
 
     @busy_bar.run("while loading conversation")
@@ -1164,7 +1166,7 @@ def generate(
     clear_history_file(filepath, new)
     prompt = Optimizers.code(prompt) if code else prompt
     prompt = Optimizers.shell_command(prompt) if shell else prompt
-    busy_bar.spin_index = busy_bar_index
+    busy_bar.spin_index = 0 if quiet else busy_bar_index
     bot.code_theme = code_theme
     bot.color = font_color
     bot.prettify = prettify
@@ -1347,11 +1349,8 @@ def main(*args):
     """Fireup console programmically"""
     sys.argv += list(args)
     args = sys.argv
-    if len(args) > 1 and not "-" in args[1]:
-        if len(args) > 1 and args[1] not in tgpt2_.commands.keys():
-            sys.argv.insert(1, "generate")  # Just a hack to make default command
-    elif len(args) == 1:
-        sys.argv.insert(1, "interactive")
+    if len(args) == 1:
+        sys.argv.insert(1, "interactive")  # Just a hack to make default command
     tgpt2_()
 
 
